@@ -1,8 +1,8 @@
-#!/usr/sbin/bash
+#!/bin/bash
 #
 #   file_names.sh - check package file names
 #
-#   Copyright (c) 2016-2021 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2016-2024 Pacman Development Team <pacman-dev@lists.archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@
 [[ -n "$LIBMAKEPKG_LINT_PACKAGE_FILE_NAMES_SH" ]] && return
 LIBMAKEPKG_LINT_PACKAGE_FILE_NAMES_SH=1
 
-LIBRARY=${LIBRARY:-'/usr/share/makepkg'}
+MAKEPKG_LIBRARY=${MAKEPKG_LIBRARY:-'/usr/share/makepkg'}
 
-source "$LIBRARY/util/message.sh"
+source "$MAKEPKG_LIBRARY/util/message.sh"
 
 lint_package_functions+=('lint_file_names')
 
