@@ -1,8 +1,8 @@
-#!/usr/sbin/bash
+#!/bin/bash
 #
 #   util.sh - utility functions for pkgbuild linting.
 #
-#   Copyright (c) 2014-2021 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2014-2024 Pacman Development Team <pacman-dev@lists.archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@
 [[ -n "$LIBMAKEPKG_LINT_PKGBUILD_UTIL_SH" ]] && return
 LIBMAKEPKG_LINT_PKGBUILD_UTIL_SH=1
 
-LIBRARY=${LIBRARY:-'/usr/share/makepkg'}
+MAKEPKG_LIBRARY=${MAKEPKG_LIBRARY:-'/usr/share/makepkg'}
 
-source "$LIBRARY/util/message.sh"
+source "$MAKEPKG_LIBRARY/util/message.sh"
 
 
 check_files_exist() {
