@@ -1,8 +1,8 @@
-#!/usr/sbin/bash
+#!/bin/bash
 #
 #   error.sh.in - error variable definitions for makepkg
 #
-#   Copyright (c) 2006-2021 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2006-2024 Pacman Development Team <pacman-dev@lists.archlinux.org>
 #   Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
@@ -39,3 +39,4 @@ E_ALREADY_BUILT=13
 E_INSTALL_FAILED=14
 E_MISSING_MAKEPKG_DEPS=15
 E_PRETTY_BAD_PRIVACY=16
+E_NOT_A_CLONE_OF=17
